org.openqa.selenium.server.htmlrunner (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV PACKAGE NEXT PACKAGE | FRAMES NO FRAMES

## Package org.openqa.selenium.server.htmlrunner

Provides classes to launch Selenium Core HTML test suites and handle their test results.

See:
Description

Interface Summary
HTMLResultsListener |

Class Summary
HTMLLauncher | Runs HTML Selenium test suites.
HTMLSuiteResult |
HTMLTestResults | A data model class for the results of the Selenium HTMLRunner (aka TestRunner, FITRunner)
SeleniumHTMLRunnerResultsHandler | Handles results of HTMLRunner (aka TestRunner, FITRunner) in automatic mode.
SingleTestSuiteResourceHandler | Generates a test suite table designed to run a single Selenium test; to use it, point TestRunner.html to /singleTest/http://my.com/single/test.html

## Package org.openqa.selenium.server.htmlrunner Description

Provides classes to launch Selenium Core HTML test suites and handle their test results.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV PACKAGE NEXT PACKAGE | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.